[![Build Status](https://travis-ci.org/MartinThoma/hwrt.svg?branch=master)](https://travis-ci.org/MartinThoma/hwrt)
[![Coverage Status](https://img.shields.io/coveralls/MartinThoma/hwrt.svg)](https://coveralls.io/r/MartinThoma/hwrt?branch=master)
[![Documentation Status](https://readthedocs.org/projects/hwrt/badge/?version=latest)](http://pythonhosted.org/hwrt)

## Handwriting Recognition Toolkit

A toolkit for handwriting recognition (HWR). Especially on-line HWR. It
was developed for the bachelor's thesis of Martin Thoma.

### Version history

* 0.1 First uploads

### Documentation

The documentation is available at https://pythonhosted.org/hwrt